@@ -49,7 +49,7 @@ struct _WnckPagerPrivate
   int prelight; /* workspace mouse is hovering over */
   gboolean prelight_dnd; /* is dnd happening? */
 
-  gboolean dragging :1;
+  guint dragging :1;
   int drag_start_x;
   int drag_start_y;
   WnckWindow *drag_window;
@@ -166,7 +166,7 @@ wnck_pager_get_type (void)
   
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (WnckPagerClass),
         (GBaseInitFunc) NULL,
@@ -565,6 +565,10 @@ get_workspace_rect (WnckPager    *pager,
 
       col = space / spaces_per_row;
       row = space % spaces_per_row;
+
+      if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
+        col = spaces_per_row - col - 1;
+
       rect->x = (rect->width + 1) * col; 
       rect->y = (rect->height + 1) * row;
       
@@ -581,6 +585,10 @@ get_workspace_rect (WnckPager    *pager,
       
       col = space % spaces_per_row;
       row = space / spaces_per_row;
+
+      if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
+        col = spaces_per_row - col - 1;
+
       rect->x = (rect->width + 1) * col; 
       rect->y = (rect->height + 1) * row;
 
