@@ -806,7 +806,7 @@ wnck_selector_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info = {
+      const GTypeInfo object_info = {
         sizeof (WnckSelectorClass),
         (GBaseInitFunc) NULL,
         (GBaseFinalizeFunc) NULL,
